# $Id: proftpd.spec,v 1.2 2006/08/08 00:46:47 kylee Exp $

# You can specify additional modules on the RPM build line by specifying
# flags like:
#
#   --with mod_tls
#
# The following modules/support can be added in this manner:
#
#   mod_tls
#   mod_radius
#   mod_ldap
#   mod_wrap
#   mod_sql
#   mod_sql_mysql
#   mod_sql_postgres
#   mod_rewrite
#   mod_ifsession
#   ipv6

%define proftpd_version 1.3.0

%define _with_mod_tls 1
%define _with_mod_ldap 1
%define _with_mod_sql 1
%define _with_mod_sql_mysql 1

Summary:		ProFTPD -- Professional FTP Server.
Name:			proftpd
Release:		2AX
License:		GPL
Group:			System Environment/Daemons
URL:			http://www.proftpd.org/
Source:			ftp://ftp.proftpd.org/distrib/%{name}-%{version}.tar.bz2
Patch0:			proftpd-1.2.9-xinetd.patch
Version:		%{proftpd_version}
Prefix:			/usr
BuildRoot:		%{_builddir}/%{name}-%{version}-root
Requires:		pam >= 0.72, chkconfig, %{?_with_mod_tls:openssl krb5-libs}, %{?_with_mod_ldap:openldap}
BuildPreReq:	pam-devel %{?_with_mod_tls:openssl-devel krb5-devel} %{?_with_mod_ldap:openldap-devel}
ExclusiveArch:		i386 x86_64 ppc ppc64 ia64
Provides:		ftpserver
Prereq:			fileutils
Obsoletes:		proftpd-core, proftpd-standalone, proftpd-xinetd
Source1:		proftpd.conf

%description
ProFTPD is an enhanced FTP server with a focus toward simplicity, security,
and ease of configuration.  It features a very Apache-like configuration
syntax, and a highly customizable server infrastructure, including support for
multiple 'virtual' FTP servers, anonymous FTP, and permission-based directory
visibility.

The base proftpd package installs standalone support. You can install the
proftpd-inetd package to enable inetd/xinetd support.

%{?_with_ipv6: This package is IPv6 enabled.}
Addtional modules enabled: mod_ratio mod_readme %{?_with_mod_tls: mod_tls}%{?_with_mod_radius: mod_radius}%{?_with_mod_ldap: mod_ldap}%{?_with_mod_wrap: mod_wrap}%{?_with_mod_sql: mod_sql}%{?_with_mod_sql_mysql: mod_sql_mysql}%{?_with_mod_sql_postgres: mod_sql_postgres}%{?_with_mod_rewrite: mod_rewrite}%{?_with_mod_ifsession: mod_ifsession}

%prep
%setup -q
%patch0 -p1 -b .xinetd
  MODULES="mod_ratio:mod_readme"
  MODULES="${MODULES}%{?_with_mod_tls::mod_tls}"
  MODULES="${MODULES}%{?_with_mod_radius::mod_radius}"
  MODULES="${MODULES}%{?_with_mod_ldap::mod_ldap}"
  MODULES="${MODULES}%{?_with_mod_wrap::mod_wrap}"
  MODULES="${MODULES}%{?_with_mod_sql::mod_sql}"
  MODULES="${MODULES}%{?_with_mod_sql_mysql::mod_sql_mysql}"
  MODULES="${MODULES}%{?_with_mod_sql_postgres::mod_sql_postgres}"
  MODULES="${MODULES}%{?_with_mod_rewrite::mod_rewrite}"
  MODULES="${MODULES}%{?_with_mod_ifsession::mod_ifsession}"
  CFLAGS="$RPM_OPT_FLAGS" ./configure \
	--prefix=%{prefix} \
	--sysconfdir=/etc \
	--localstatedir=/var/run \
	--mandir=%_mandir \
	%{?_with_mod_tls:--with-includes=/usr/kerberos/include} \
	%{?_with_mod_sql_mysql:--with-includes=%{_includedir}/mysql} \
	%{?_with_mod_sql_mysql:--with-libraries=%{_libdir}/mysql} \
	%{?_with_ipv6:--enable-ipv6} \
	--with-modules=${MODULES}

%build
  make

%install
  rm -rf $RPM_BUILD_ROOT
  make prefix=$RPM_BUILD_ROOT%{prefix} \
	exec_prefix=$RPM_BUILD_ROOT%{prefix} \
	sysconfdir=$RPM_BUILD_ROOT/etc \
    mandir=$RPM_BUILD_ROOT/%_mandir \
	localstatedir=$RPM_BUILD_ROOT/var/run \
	rundir=$RPM_BUILD_ROOT/var/run/proftpd \
	INSTALL_USER=`id -un` INSTALL_GROUP=`id -gn` \
    install
  #mkdir -p $RPM_BUILD_ROOT/home/ftp
  mkdir -p %{buildroot}/var/ftp/uploads
  mkdir -p %{buildroot}/var/ftp/pub
  mkdir -p %{buildroot}/var/log/proftpd

  mkdir -p $RPM_BUILD_ROOT/etc/pam.d
  install -m 644 contrib/dist/rpm/ftp.pamd $RPM_BUILD_ROOT/etc/pam.d/ftp
%ifarch x86_64 ppc64
  perl -spi -e 's!lib/!lib64/!' $RPM_BUILD_ROOT/etc/pam.d/ftp
%endif
  install -m 644 %{SOURCE1} $RPM_BUILD_ROOT/etc/proftpd.conf
  mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
  sed -e '/FTPSHUT=/c\' \
	  -e 'FTPSHUT=%{prefix}/sbin/ftpshut' \
	contrib/dist/rpm/proftpd.init.d >contrib/dist/rpm/proftpd.init.d.tmp
  mv --force contrib/dist/rpm/proftpd.init.d.tmp contrib/dist/rpm/proftpd.init.d
  install -m 755 contrib/dist/rpm/proftpd.init.d $RPM_BUILD_ROOT/etc/rc.d/init.d/proftpd
  mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d/
  install -m 644 contrib/dist/rpm/proftpd.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/proftpd
  mkdir -p $RPM_BUILD_ROOT/etc/xinetd.d/
  install -m 644 contrib/dist/rpm/xinetd $RPM_BUILD_ROOT/etc/xinetd.d/proftpd-xinetd
  # We don't want this dangling symlinks to make it into the RPM
  rm -f contrib/README.mod_sql
  mkdir -p $RPM_BUILD_ROOT/%{_docdir}
  install -m 644 COPYING CREDITS ChangeLog NEWS $RPM_BUILD_ROOT/%{_docdir}


%pre
  if [ ! -f /etc/ftpusers ]; then
  	touch /etc/ftpusers
  	IFS=":"
	while { read username nu nu gid nu; }; do
		if [ $gid -le 100 -a "$username" != "ftp" ]; then
			echo $username
		fi
  	done < /etc/passwd >/etc/ftpusers
  fi

%preun
  if [ "$1" = 0 ]; then
    if [ -d /var/run/proftpd ]; then
		rm -rf /var/run/proftpd/*
    fi
    /sbin/chkconfig --del proftpd
  fi

%post
  /sbin/chkconfig --add proftpd
  if [ $1 = 1 ]; then
    # Force the "ServerType" directive for this operation type.
    tmpfile=/tmp/proftpd-conf.$$
    sed -e '/ServerType/c\' \
      -e 'ServerType	standalone' \
      /etc/proftpd.conf >$tmpfile
    mv $tmpfile /etc/proftpd.conf
  fi

%postun
if [ $1 -ge 1 ]; then
	. /etc/rc.d/init.d/functions > /dev/null 2>&1
	status proftpd > /dev/null 2>&1
	if [ $? -eq 0 ]; then
		/sbin/service proftpd restart > /dev/null 2>&1
	fi
fi

%clean
rm -rf $RPM_BUILD_ROOT
rm -rf %{_builddir}/%{name}-%{version}

%files
%defattr(-,root,root)
%{prefix}/sbin/*
%{prefix}/bin/*
%dir /var/run/proftpd
%attr(0755,ftp,ftp) %dir /var/ftp
%attr(0755,ftp,ftp) %dir /var/ftp/*
/etc/rc.d/init.d/proftpd
%config(noreplace) /etc/proftpd.conf
%config(noreplace) /etc/pam.d/ftp
%config(noreplace) /etc/logrotate.d/proftpd
%config(noreplace) /etc/xinetd.d/proftpd-xinetd
%attr(0700, -, -)  %dir /var/log/proftpd

%doc COPYING CREDITS ChangeLog NEWS
%doc README* doc/*
%doc contrib/README* contrib/xferstats.holger-preiss
%doc sample-configurations
%_mandir/*/*


%changelog
* Mon Aug 07 2006 Ki-Young, Lee <kylee@haansoft.com> 1.3.0-2AX
- change proftpd.conf( remove AuthPAMAuthoritative )

* Wed Jul 19 2006 Ki-Young, Lee <kylee@haansoft.com> 1.3.0-1AX
- Update to 1.3.0
- Fixed handling of REST commands using negative numbers
- Worked around glibc-2.3 issues with looking up timezone information when the process has been chrooted.
- Fixed handling of CPPFLAGS and LDFLAGS settings with regards to
  the --with-includes and --with-libraries configure options.

* Fri Mar 31 2006 Hiroshi HARA <hhara@miraclelinux.com> 1.2.10-5AX
- add %postun section to restart proftpd when updated

* Wed Sep 14 2005 Zhongyong Li <zylee@redflag-linux.com> 1.2.10-4AX
- modify the spec file to support ia64 architecture

* Thu Jul 19 2005 Brian Woo <jkwoo@haansoft.com> 1.2.10-3AX
- ppc package has to use lib in pam - bugzillaAX 836
- prevent uploading from anonymous user - bugzillaAX 837

* Sun May 1 2005 brian Woo <jkwoo@haansoft.com> 1.2.10-2AX
- added the build option on ppc, x86_64 machine. - bugzillaAX 177
- config file change

* Tue Dec 14 2004 Hua Jie <jiehua@redflag-linux.com> 1.2.10-1AX
- update to 1.2.10

* Wed Nov 10 2004 Jun YOSHIDA <jun@miraclelinux.com> 1.2.9-5AX
- setup command shows us duplicated entries for proftpd so we changed
- the name of file from /etc/xinetd.d/proftpd to /etc/xinetd.d/proftpd-xinetd

* Thu Aug 26 2004 Shiro Yamada <shiro@miraclelinux.com> 1.2.9-4AX
- applied a fix for CAN-2004-0432, CIDR based ACL issue (patch1)

* Fri Mar 17 2004 Yi Hua <hua.yi@oracle.com> 1.2.9-3AX
disable the proftp in the /etc/xinetd.d/proftpd config file
* Fri Feb 20 2004 Yasuma Takeda <yasuma@miraclelinux.com> 1.2.9-2AX
- rebuild for Asianux
- add mod_ldap, mod_tls, mod_sql, mod_mysql, mod_pgsql
- removed proftpd-inetd

* Tue Sep 23 2003 Daniel Roesen <dr@proftpd.org>
- Added "--with ipv6" to enable IPv6 support while building the RPM

* Sun May 25 2003 John Morrissey <jwm@horde.net>
- Permit selection of additional contrib modules when building the RPM
  Submitted by: Ivan F. Martinez <ivanfm@users.sourceforge.net>

* Sat Nov  2 2002 John Morrissey <jwm@horde.net>
- Don't let dangling contrib/README.* symlinks get into the built RPM
- logrotate for xferlog

* Wed Aug 14 2002 John Morrissey <jwm@horde.net>
- Added removal of build leftover directory in %clean.
  Submitted by: Christian Pelealu <kurisu@mweb.co.id>

* Wed Jul  3 2002 John Morrissey <jwm@horde.net> 1.2.6rc1-1
- 1.2.6rc1 release.

* Sun Jun  9 2002 John Morrissey <jwm@horde.net> 1.2.5-1
- 1.2.5 release.

* Fri May 10 2002 TJ Saunders <tj@castaglia.org>
- Added use of %defattr to allow build of RPMs by non-root users
  For details see http://bugs.proftpd.org/show_bug.cgi?id=1580

* Mon Mar 05 2001 Daniel Roesen <droesen@entire-systems.com>
- PAM >= 0.72 is now a requirement. Versions before are broken and
  Red Hat provides a PAM update for all RH 6.x releases. See:
  http://www.redhat.com/support/errata/RHSA-2000-120.html
  Thanks to O.Elliyasa <osman@Cable.EU.org> for the suggestion.
  For details see http://bugs.proftpd.org/show_bug.cgi?id=1048
- release: 1.2.1-2

* Wed Mar 01 2001 Daniel Roesen <droesen@entire-systems.com>
- Update to 1.2.1
- release: 1.2.1-1

* Wed Feb 27 2001 Daniel Roesen <droesen@entire-systems.com>
- added "Obsoletes: proftpd-core" to make migration to new RPMs easier.
  Thanks to Sbastien Prud'homme <prudhomme@easy-flying.com> for the hint.
- release: 1.2.0-3

* Wed Feb 26 2001 Daniel Roesen <droesen@entire-systems.com>
- cleaned up .spec formatting (cosmetics)
- fixed CFLAGS (fixes /etc/shadow support)
- included COPYING, CREDITS, ChangeLog and NEWS
- Renamed main package from "proftpd-core" to just "proftpd"
- release: 1.2.0-2

* Wed Feb 14 2001 Daniel Roesen <droesen@entire-systems.com>
- moved Changelog to bottom
- fixed %pre script /etc/ftpusers generator
- removed /ftp/ftpusers from package management. Deinstalling ProFTPD
  should _not_ result in removal of this file.

* Thu Oct 03 1999 O.Elliyasa <osman@Cable.EU.org>
- Multi package creation.
  Created core, standalone, inetd (&doc) package creations.
  Added startup script for init.d
  Need to make the "standalone & inetd" packages being created as "noarch"
- Added URL.
- Added prefix to make the package relocatable.

* Wed Sep 08 1999 O.Elliyasa <osman@Cable.EU.org>
- Corrected inetd.conf line addition/change logic.

* Sat Jul 24 1999 MacGyver <macgyver@tos.net>
- Initial import of spec.
